@@ -75,13 +75,13 @@ def makeIndividualData(file):
         except AttributeError as e:
             pass
 
-    df['labels'] = df['labels'].fillna('undefined')
-    df.loc[df['labels'] == 'company', 'num_labels'] = 1
-    df.loc[df['labels'] == 'address', 'num_labels'] = 2
-    df.loc[df['labels'] == 'date', 'num_labels'] = 3
-    df.loc[df['labels'] == 'total', 'num_labels'] = 4
-    df.loc[df['labels'] == 'invoice', 'num_labels'] = 5
-    df.loc[df['labels'] == 'undefined', 'num_labels'] = 6
+    df['Tag'] = df['Tag'].fillna('undefined')
+    df.loc[df['Tag'] == 'company', 'num_labels'] = 1
+    df.loc[df['Tag'] == 'address', 'num_labels'] = 2
+    df.loc[df['Tag'] == 'date', 'num_labels'] = 3
+    df.loc[df['Tag'] == 'total', 'num_labels'] = 4
+    df.loc[df['Tag'] == 'invoice', 'num_labels'] = 5
+    df.loc[df['Tag'] == 'undefined', 'num_labels'] = 6
 
     assert df[
                'num_labels'].isnull().values.any() == False, f'labeling error! Invalid label(s) present in {file}.csv, df:{df}'
